# MP-Search

Django simple search app.

### Installation

Install with pip:

```
$ pip install django-model-search
```

### Example

```
>>> from model_search import model_search
>>> results = model_search(search_query, objects, ['field1_name', 'field2_name'])
```
